%% Color-Based Segmentation Using K-Means Clustering
% adattato da una demo di Matlab

method = 'kmeans'; %arbib;
featType = 4; %1:6;
display = 1;
reps = 1;
%% Step 1: Read Image

close all;
[imgName, path] = uigetfile('../img/*.*', 'pick up one image');
img = imread([path imgName]);
[nrows,ncols, ~] = size(img);

nClusters = input('Insert the number of clusters: ');
typeFeat = [{'gray'}, {'gray+XY'}, {'RGB'}, {'RGB+XY'}, {'Lab'}, {'Lab+XY'}];
features = computeFeatures(img, typeFeat{5});

switch method
    case{'kmeans'}
        [cluster_idx,centroids] = kmeans(features, nClusters,'distance','sqEuclidean', ...
        'Replicates',reps,'emptyaction','drop', 'start', 'sample');
    case{'arbib'}
        [cluster_idx,centroids] = arbib(features,nClusters);
    otherwise
        error('Input a valid clustering method');
end

pixel_labels = reshape( cluster_idx, nrows, ncols );

segmented_images = cell( 1, nClusters );
edges = cell( 1, nClusters );

rgb_label = repmat( pixel_labels, [1 1 3] );

for k = 1:nClusters
    color = img;
    color( rgb_label ~= k ) = 0;
    segmented_images{k} = color;
    
    temp = rgb2gray( segmented_images{k} );
    edges{k} = edge( temp,'sobel' );
   
end

% display
n = 3; % columns of the subplot
m = ceil( ( nClusters + 2 ) / n ); % rows of the subplot
fig = figure( 'name', [method ' clustering in ' typeFeat{featType} ' feature space']);
hold on
subplot( m, n, 1 )
imshow( img )
text(size( img,2), size(img,1)+15,...
     'originale', ...
     'FontSize',7,'HorizontalAlignment','right');
subplot( m, n, 2 );
imshow( pixel_labels,[] )
text(size( pixel_labels,2), size(pixel_labels,1)+15,...
     'etichette', ...
     'FontSize',7,'HorizontalAlignment','right');
for k = 1:nClusters
    subplot( m, n, 2+k )
    imshow( segmented_images{k} );
    text(size( segmented_images{k},2), size(segmented_images{k},1)+15,...
     [ 'cluster ' num2str(k) ], ...
     'FontSize',7,'HorizontalAlignment','right');
end
hold off